.. commit signature, "date_str author_str sha_str"
   Maintain spacing of "History" and "GitHub Log" titles

History
=======


RocketUnits History
-------------------

**RocketUnits** was largely developed on the three companion projects
`RocketCEA <https://rocketcea.readthedocs.io/en/latest/>`__ ,
`RocketIsp <https://rocketisp.readthedocs.io/en/latest/>`__ and 
`RocketProps <https://rocketprops.readthedocs.io/en/latest/>`__.

`RocketCEA <https://rocketcea.readthedocs.io/en/latest/>`__
makes direct calls to the NASA FORTRAN CEA code in “rocket” mode to 
calculate Isp, Cstar, Tcham etc. and provides tools to help determine 
useful mixture ratio range, optimum MR and more.

`RocketIsp <https://rocketisp.readthedocs.io/en/latest/>`__ uses a simplified JANNAF 
approach to calculate delivered specific impulse (Isp) for liquid rocket thrust chambers.

`RocketProps <https://rocketprops.readthedocs.io/en/latest/>`__
calculates the various liquid propellant properties required to analyse 
a liquid propellant thrust chamber.


GitHub Log
----------

* May 04, 2021
    - (by: sonofeft)
        - First Created RocketUnits with PyHatch

